@@ -1,27 +1,30 @@
 /*
  * dbus_functions.c - methods for work with webauth application
- * This file is part of libvkontakte library
+ * This file is part of MySocials driver library
  *
- * Copyright (C) 2010 - Sergey Zakharov
+ * Copyright (C) 2010 - MySocials team
  *
- * libvkontakte library is free software; you can redistribute it and/or modify
+ * MySocials driver library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * libvkontakte library is distributed in the hope that it will be useful,
+ * MySocials driver library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with libvkontakte library; if not, write to the Free Software
+ * along with MySocials driver library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA  02110-1301  USA
  */
 
 #include "dbus_functions.h"
 
+/* For dbus_connection_setup_with_g_main method */
+#include <dbus/dbus-glib-lowlevel.h>
+
 #define ATTEMPTS_COUNT 5
 /**
  * Utility to terminate if given DBusError is set.
@@ -29,18 +32,16 @@
  *
  * If error is not set, will do nothing.
  */
-void terminateOnError(const char* msg,
+int terminateOnError(const char* msg,
                              const DBusError* error) {
 
-  assert(msg != NULL);
-  assert(error != NULL);
-
   if (dbus_error_is_set(error)) {
-    fprintf(stderr, msg);
+    fprintf(stderr, "%s\n", msg);
     fprintf(stderr, "DBusError.name: %s\n", error->name);
     fprintf(stderr, "DBusError.message: %s\n", error->message);
-    exit(EXIT_FAILURE);
+    return 1;
   }
+  return 0;
 }
 
 /**
@@ -64,11 +65,10 @@ char* webauth(char* url, char* proxy, char* port, char* user, char* pass, char**
     dbus_error_init(&error);
 
     msa_debug("Connecting to Session D-Bus\n");
-    bus = dbus_bus_get(DBUS_BUS_SESSION, &error);
-    terminateOnError("Failed to open Session bus\n", &error);
-    assert(bus != NULL);
-
-    terminateOnError("Failed to check for name ownership\n", &error);
+    if (((bus = dbus_bus_get(DBUS_BUS_SESSION, &error)) == NULL)
+       || (terminateOnError("Failed to open Session bus\n", &error))
+       || (terminateOnError("Failed to check for name ownership\n", &error)))
+        return NULL;
 
   /* Construct a DBusMessage that represents a method call.
      Parameters will be added later. The internal type of the message
@@ -116,7 +116,7 @@ char* webauth(char* url, char* proxy, char* port, char* user, char* pass, char**
         msg = NULL;
     }
 
-//Authorization request
+/* Authorization request */
 
     msa_debug("Creating a message object\n");
     msg = dbus_message_new_method_call(SYSNOTE_NAME, /* destination */
@@ -198,20 +198,19 @@ void receive(char** url, char* client_id)
     char **response = NULL;
     int attempts = 0;
     int len;
-
+    GMainContext *context;
+    
     msa_debug("Listening for signals for %s\n", client_id);
 
-    // initialise the errors
+    /* initialise the errors */
     dbus_error_init(&err);
 
-    GMainContext *context;
     context = g_main_context_new();
     msa_debug("Create context\n");
 
-    // connect to the bus and check for errors
-    
+    /* connect to the bus and check for errors */    
     msa_debug("Create connection\n");
-    conn = dbus_bus_get(DBUS_BUS_SESSION, &err);
+    conn = dbus_bus_get_private(DBUS_BUS_SESSION, &err);
     msa_debug("Setup connection\n");
     dbus_connection_setup_with_g_main(conn, context);
 
@@ -221,27 +220,29 @@ void receive(char** url, char* client_id)
     }
 
     if (NULL == conn) { 
+        g_main_context_unref(context);
         return;
     }
 
 
-    // add a rule for which messages we want to see
+    /* add a rule for which messages we want to see */
     dbus_bus_add_match(conn, SEARCH_RULE, &err); 
     dbus_connection_flush(conn);
     if (dbus_error_is_set(&err)) { 
         fprintf(stderr, "Match Error (%s)\n", err.message);
-        dbus_connection_unref(conn);
+        dbus_connection_close(conn);
+        g_main_context_unref(context);
         return; 
     }
     msa_debug("Match rule sent\n");
 
-    // loop listening for signals being emmitted
-    //wait wile webauth application start
+    /* loop listening for signals being emmitted */
+    /* wait wile webauth application start       */
     sleep(3);
     while (1) {
         msa_debug("wait response\n");
 
-        // non blocking read of the next available message
+        /* non blocking read of the next available message */
 
         if(!dbus_connection_read_write(conn, 0))
             attempts++;
@@ -250,7 +251,7 @@ void receive(char** url, char* client_id)
 
         msg = dbus_connection_pop_message(conn);
 
-        // loop again if we haven't read a message
+        /* loop again if we haven't read a message */
         if (NULL == msg) { 
             if (!dbus_bus_name_has_owner(conn, SYSNOTE_NAME, &err)) {
                 fprintf(stderr, "Name has no owner on the bus!\n");
@@ -261,10 +262,10 @@ void receive(char** url, char* client_id)
             continue;
         }
 
-        // check if the message is a signal from the correct interface and with the correct name
-        if (dbus_message_is_signal(msg, SYSNOTE_NAME, SYSNOTE_SIGNAL)) {
+        /* check if the message is a signal from the correct interface and with the correct name */
+        if (dbus_message_is_signal(msg, SYSNOTE_NAME, DRIVER_ID)) {
          
-            // read the parameters
+            /* read the parameters */
             if (!dbus_message_iter_init(msg, &args))
                 fprintf(stderr, "Message Has No Parameters\n");
             else if (DBUS_TYPE_ARRAY != dbus_message_iter_get_arg_type(&args)) {
@@ -282,10 +283,10 @@ void receive(char** url, char* client_id)
                         *url = g_strdup(response[1]);
                     } else {
                         dbus_free_string_array(response);
-                        dbus_message_unref(msg); 	
+                        dbus_message_unref(msg);
                         continue;
                     }
-                    dbus_free_string_array(response); 	
+                    dbus_free_string_array(response);
                 }
             }
 
@@ -293,36 +294,11 @@ void receive(char** url, char* client_id)
             break;
         }
 
-        // free the message
+        /* free the message */
         dbus_message_unref(msg);
     }
-/*
-   // create a signal & check for errors 
-   msg = dbus_message_new_signal(SYSNOTE_OPATH, // object name of the signal
-                                 SYSNOTE_NAME, // interface name of the signal
-                                 SYSNOTE_SIGNAL_SHUTDOWN); // name of the signal
-   if (NULL == msg) 
-   { 
-      fprintf(stderr, "Message Null\n"); 
-      dbus_connection_unref(conn);
-      return;
-   }
 
- 
-   // send the message and flush the connection
-   if (!dbus_connection_send(conn, msg, NULL)) {
-      fprintf(stderr, "Out Of Memory!\n");
-      dbus_message_unref(msg);
-      dbus_connection_unref(conn); 
-      return;
-   }
-   dbus_connection_flush(conn);
-   
-   printf("Signal Sent\n");
-  
-   // free the message 
-   dbus_message_unref(msg);
-*/
-   dbus_connection_unref(conn); 
+   dbus_connection_close(conn); 
+   g_main_context_unref(context);
 }
 
