@@ -68,9 +68,14 @@ DRiATmZzURmZPTY6t4YBDpl5PpVteROZiPB/dp1sFwOEwK8AAAAASUVORK5CYII="
 
 #define AUTH_REQUEST "<Request class='settings' function='authorization'><Params/></Request>"
 
+#define RESPONSE_EMPTY "<?xml version=\"1.0\"?><response></response>"
+
 #define MSG_AUTH_ERROR "<error><error_code>1"DRV_AUTH_ERROR_CODE"</error_code>\
                               <error_msg>"DRV_AUTH_ERROR"</error_msg></error>"
 
+#define MSG_AUTH_CANCEL "<error><error_code>1"DRV_AUTH_CANCEL_CODE"</error_code>\
+                              <error_msg>"DRV_AUTH_CANCEL"</error_msg></error>"
+
 #define MSG_NETWORK_ERROR "<error><error_code>1"DRV_NETW_ERROR_CODE"</error_code>\
                               <error_msg>"DRV_NETW_ERROR"</error_msg></error>"
 
